Heic2pngPlatform class abstract

The interface that platform-specific implementations of heic2png must extend.

Inheritance
  • Object
  • PlatformInterface
  • Heic2pngPlatform
Implementers

Constructors

Heic2pngPlatform()
Creates a new Heic2pngPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(String inputPath, String outputPath, {int compressionLevel = 6, bool preserveMetadata = true}) Future<bool>
Converts a HEIC/HEIF file at inputPath to PNG at outputPath.
convertToBytes(String inputPath, {int compressionLevel = 6, bool preserveMetadata = true}) Future<Uint8List>
Converts a HEIC/HEIF file at inputPath to PNG bytes in memory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Heic2pngPlatform
The current platform-specific implementation of Heic2pngPlatform.
getter/setter pair